@@ -9,14 +9,15 @@ def f(filepath, content):
     φ.write(content)
     return content
 
-_filepath = './_/temp.txt'
+_root = './temp_save_string'
+_filepath = f'{_root}/temp.txt'
 
-setup = lambda: (mkdir if not exists('_') else nopx)('_')
+setup = lambda: (mkdir if not exists(_root) else nopx)(_root)
 
 def tear_down():
   if exists(_filepath):
     remove(_filepath)
-  rmdir('./_')
+  rmdir(_root)
 
 def t():
   setup()
